@@ -13,18 +13,21 @@ AccessKey is required when operating with dataset.
 
 """
 
+import logging
 from typing import Any, Dict, Generator, Optional, Type, Union, overload
 
 from typing_extensions import Literal
 
 from ..dataset import Dataset, FusionDataset
 from ..exception import DatasetTypeError, ResourceNotExistError
-from ..utility import KwargsDeprecated
 from .dataset import DatasetClient, FusionDatasetClient
+from .log import UPLOAD_DATASET_RESUME_TEMPLATE
 from .requests import Client, PagingList, Tqdm
 
 DatasetClientType = Union[DatasetClient, FusionDatasetClient]
 
+logger = logging.getLogger(__name__)
+
 
 class GAS:
     """:class:`GAS` defines the initial client to interact between local and TensorBay.
@@ -287,32 +290,16 @@ class GAS:
         ReturnType: Type[DatasetClientType] = FusionDatasetClient if is_fusion else DatasetClient
         return ReturnType(name, dataset_id, self, commit_id=commit_id)
 
-    @KwargsDeprecated(
-        ("start", "stop"),
-        since="1.3.0",
-        removed_in="1.5.0",
-        substitute="PagingList[start:stop]",
-    )
-    def list_dataset_names(self, **kwargs: int) -> PagingList[str]:
+    def list_dataset_names(self) -> PagingList[str]:
         """List names of all TensorBay datasets.
 
-        Arguments:
-            kwargs: For deprecated keyword arguments: "start" and "stop".
-
         Returns:
             The PagingList of all TensorBay dataset names.
 
         """
-        start = kwargs.get("start")
-        stop = kwargs.get("stop")
-        paging_list = PagingList(
-            lambda offset, limit: self._generate_dataset_names(None, False, offset, limit),
-            128,
+        return PagingList(
+            lambda offset, limit: self._generate_dataset_names(None, False, offset, limit), 128
         )
-        if start is not None or stop is not None:
-            return paging_list[start:stop]
-
-        return paging_list
 
     def rename_dataset(self, name: str, new_name: str) -> None:
         """Rename a TensorBay Dataset with given name.
@@ -394,6 +381,9 @@ class GAS:
             :class:`~tensorbay.client.dataset.FusionDatasetClient`
             bound with the uploaded dataset.
 
+        Raises:
+            Exception: When Exception was raised during uploding dataset.
+
         """
         dataset_client = self.get_dataset(dataset.name, isinstance(dataset, FusionDataset))
         if draft_number:
@@ -401,19 +391,27 @@ class GAS:
         else:
             dataset_client.create_draft()
 
-        if dataset.catalog:
-            dataset_client.upload_catalog(dataset.catalog)
+        try:
+            if dataset.catalog:
+                dataset_client.upload_catalog(dataset.catalog)
 
-        dataset_client.update_notes(**dataset.notes)  # type: ignore[arg-type]
+            dataset_client.update_notes(**dataset.notes)  # type: ignore[arg-type]
 
-        with Tqdm(sum(len(segment) for segment in dataset), disable=quiet) as pbar:
-            for segment in dataset:
-                dataset_client._upload_segment(  # pylint: disable=protected-access
-                    segment,  # type: ignore[arg-type]
-                    jobs=jobs,
-                    skip_uploaded_files=skip_uploaded_files,
-                    pbar=pbar,
-                )
+            with Tqdm(sum(len(segment) for segment in dataset), disable=quiet) as pbar:
+                for segment in dataset:
+                    dataset_client._upload_segment(  # pylint: disable=protected-access
+                        segment,  # type: ignore[arg-type]
+                        jobs=jobs,
+                        skip_uploaded_files=skip_uploaded_files,
+                        pbar=pbar,
+                    )
+        except Exception:
+            logger.error(
+                UPLOAD_DATASET_RESUME_TEMPLATE,
+                dataset_client.status.draft_number,
+                dataset_client.status.draft_number,
+            )
+            raise
 
         return dataset_client
 
